@@ -1,10 +1,10 @@
 package Benchmark::Perl::Formance;
-# git description: v0.37-14-g96ffee5
+# git description: v0.38-6-g08c42de
 
 BEGIN {
   $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
 }
-$Benchmark::Perl::Formance::VERSION = '0.38';
+$Benchmark::Perl::Formance::VERSION = '0.39';
 use 5.008;
 
 use warnings;
@@ -15,7 +15,6 @@ use Config::Perl::V;
 use Exporter;
 use Getopt::Long ":config", "no_ignore_case", "bundling";
 use Data::Structure::Util "unbless";
-use Data::YAML::Writer;
 use Time::HiRes qw(gettimeofday);
 use Devel::Platform::Info;
 use List::Util "max";
@@ -677,15 +676,8 @@ sub print_outstyle_yaml
 {
         my ($self, $RESULTS) = @_;
 
-        my $output = '';
-        my $indent = $self->{options}{indent};
-        my $yw = new Data::YAML::Writer;
-        $yw->write($RESULTS, sub { $output .= shift()."\n" });
-        $output =~ s/^/" "x$indent/emsg; # indent
-
-        my $tapdescription = $self->{options}{tapdescription};
-        $output = "ok $tapdescription\n".$output if $tapdescription;
-        print $output;
+        require YAML;
+        print YAML::Dump($RESULTS);
 }
 
 sub print_outstyle_json
@@ -693,8 +685,24 @@ sub print_outstyle_json
         my ($self, $RESULTS) = @_;
 
         require JSON;
-        my $json = JSON->new->allow_nonref;
-        print $json->pretty->encode( $RESULTS );
+        print JSON->new->allow_nonref->pretty->encode( $RESULTS );
+}
+
+sub print_outstyle_yamlish
+{
+        my ($self, $RESULTS) = @_;
+
+        require Data::YAML::Writer;
+
+        my $output = '';
+        my $indent = $self->{options}{indent};
+        my $yw = Data::YAML::Writer->new;
+        $yw->write($RESULTS, sub { $output .= shift()."\n" });
+        $output =~ s/^/" "x$indent/emsg; # indent
+
+        my $tapdescription = $self->{options}{tapdescription};
+        $output = "ok $tapdescription\n".$output if $tapdescription;
+        print $output;
 }
 
 sub find_interesting_result_paths
@@ -741,8 +749,8 @@ sub print_results
         my ($self, $RESULTS) = @_;
         return if $self->{options}{quiet};
 
-        my $outstyle = $self->{options}{outstyle};
-        $outstyle = "summary" unless $outstyle =~ qr/^(summary|yaml|json)$/;
+        my $outstyle = lc $self->{options}{outstyle};
+        $outstyle = "summary" unless $outstyle =~ qr/^(summary|yaml|yamlish|json)$/;
         my $sub = "print_outstyle_$outstyle";
 
         $self->$sub($RESULTS);
